The Elm Installer
=================

We have a way to use ``npm install elm``, however it is often hard to use.
This is an attempt to create a pypi installer so that we can use: ``pip install elm-lang`` instead.

Learn about the Elm programming language at `elm-lang.org <http://elm-lang.org/>`_.


Install
-------

.. code-block:: console

    $ pip install elm-lang --no-cache-dir
    $ elm --version
    0.19.0

Help
----

If you are stuck, ask around on `the Elm slack channel`_. Folks are friendly and happy to help with questions!

.. _`the Elm slack channel`: http://elmlang.herokuapp.com/
